# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._operations import AppsOperations
from ._operations import AzureRegionsOperations
from ._operations import CdfClustersOperations
from ._operations import CountriesOperations
from ._operations import CustomersOperations
from ._operations import DatabasesOperations
from ._operations import PowerOperations
from ._operations import PresentationOperations
from ._operations import TenantsOperations
from ._operations import UserOperations

from ._patch import __all__ as _patch_all
from ._patch import *  # type: ignore # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AppsOperations",
    "AzureRegionsOperations",
    "CdfClustersOperations",
    "CountriesOperations",
    "CustomersOperations",
    "DatabasesOperations",
    "PowerOperations",
    "PresentationOperations",
    "TenantsOperations",
    "UserOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
