# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class CustomerStatusDto(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """CustomerStatusDto."""

    DRAFT = "Draft"
    ACTIVE = "Active"
    DEACTIVATED = "Deactivated"


class TenantEnvironment(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """TenantEnvironment."""

    PROD = "Prod"
    QA = "QA"
    TEST = "Test"
    DEV = "Dev"


class TenantInfrastructureStatus(int, Enum, metaclass=CaseInsensitiveEnumMeta):
    """TenantInfrastructureStatus."""

    ZERO = 0
    ONE = 1
    TWO = 2
    NINE = 9
